@@ -173,35 +173,32 @@ test_that("atime_grid ok when THREADS used", {
   expect_equal(length(expr.list), 3)
 })
 
-test_that("error for expr.list not list", {
-  expr.list <- atime::atime_grid(
-    list(ENGINE=c(
-      if(requireNamespace("re2"))"RE2",
-      "PCRE",
-      if(requireNamespace("stringi"))"ICU")),
-    nc=nc::capture_first_vec(subject, pattern, engine=ENGINE))
-  dolist <- function(elist){
-    atime::atime(
-      N=1:25,
-      setup={
-        rep.collapse <- function(chr)paste(rep(chr, N), collapse="")
-        subject <- rep.collapse("a")
-        pattern <- list(maybe=rep.collapse("a?"), rep.collapse("a"))
-      },
-      expr.list=elist)
-  }
-  atime.list <- dolist(expr.list)
-  expect_is(atime.list, "atime")
-  expect_error({
-    dolist(structure(2, class=c("foo","bar")))
-  }, "expr.list should be a list of expressions to run for various N, but has classes foo, bar")
+test_that("atime_grid symbol.params arg OK", {
+  grid.result <- atime::atime_grid(list(
+    PERL=TRUE,
+    FUN="strcapture"
+  ),
+  foo=FUN(regex, text, proto, perl = PERL),
+  symbol.params="FUN")
+  expect_identical(grid.result, list("foo PERL=TRUE,FUN=strcapture"=quote(strcapture(regex, text, proto, perl=TRUE))))
 })
 
-test_that("only one value in grid is OK", {
-  expr.list <- atime::atime_grid(
-    list(ENGINE="PCRE"),
-    nc=nc::capture_first_vec(subject, pattern, engine=ENGINE))
-  expect_identical(names(expr.list), "nc ENGINE=PCRE")
+test_that("atime_grid error for list of funs", {
+  expect_error({
+    atime::atime_grid(list(FUN=list(gsub)), strcapture=FUN(regex, text, proto, perl = TRUE))
+  }, "param.list elements must be atomic, but some are not: FUN")
+})
+
+test_that("atime_grid error for un-named expr in ...", {
+  expect_error({
+    atime::atime_grid(list(FUN=1:2), FUN(regex, text, proto, perl = TRUE))
+  }, "each expression in ... must be named")
+})
+
+test_that("atime_grid error for args named sorted, unique", {
+  expect_error({
+    atime::atime_grid(list(sorted=1:2), foo=FUN(regex, text, proto, perl = TRUE))
+  }, "param.list must not have elements named: sorted")
 })
 
 test_that("null is faster than wait", {
@@ -342,3 +339,35 @@ test_that("atime_versions error when no versions specified", {
   }, "need to specify at least one git SHA, in either sha.vec, or ...", fixed=TRUE)
 })
 
+if(requireNamespace("nc")){
+  test_that("only one value in grid is OK", {
+    expr.list <- atime::atime_grid(
+      list(ENGINE="PCRE"),
+      nc=nc::capture_first_vec(subject, pattern, engine=ENGINE))
+    expect_identical(names(expr.list), "nc ENGINE=PCRE")
+  })
+  test_that("error for expr.list not list", {
+    expr.list <- atime::atime_grid(
+      list(ENGINE=c(
+        if(requireNamespace("re2"))"RE2",
+        "PCRE",
+        if(requireNamespace("stringi"))"ICU")),
+      nc=nc::capture_first_vec(subject, pattern, engine=ENGINE))
+    dolist <- function(elist){
+      atime::atime(
+        N=1:25,
+        setup={
+          rep.collapse <- function(chr)paste(rep(chr, N), collapse="")
+          subject <- rep.collapse("a")
+          pattern <- list(maybe=rep.collapse("a?"), rep.collapse("a"))
+        },
+        expr.list=elist)
+    }
+    atime.list <- dolist(expr.list)
+    expect_is(atime.list, "atime")
+    expect_error({
+      dolist(structure(2, class=c("foo","bar")))
+    }, "expr.list should be a list of expressions to run for various N, but has classes foo, bar")
+  })
+}
+
